aboutsummaryrefslogtreecommitdiffhomepage
path: root/unsupported/Eigen/src/FFT
diff options
context:
space:
mode:
authorGravatar Jitse Niesen <jitse@maths.leeds.ac.uk>2012-04-15 11:06:28 +0100
committerGravatar Jitse Niesen <jitse@maths.leeds.ac.uk>2012-04-15 11:06:28 +0100
commit3c412183b2d4a131239275f440d15677cc5649b0 (patch)
tree42784a65d3ad0cc4fb912032ecdf9059aad5eb7a /unsupported/Eigen/src/FFT
parent84c93b048ecab7c22291503e68c47b6e3264fbb0 (diff)
Get rid of include directives inside namespace blocks (bug #339).
Diffstat (limited to 'unsupported/Eigen/src/FFT')
-rw-r--r--unsupported/Eigen/src/FFT/ei_fftw_impl.h4
-rw-r--r--unsupported/Eigen/src/FFT/ei_kissfft_impl.h5
2 files changed, 8 insertions, 1 deletions
diff --git a/unsupported/Eigen/src/FFT/ei_fftw_impl.h b/unsupported/Eigen/src/FFT/ei_fftw_impl.h
index a06f6739e..5c36db70c 100644
--- a/unsupported/Eigen/src/FFT/ei_fftw_impl.h
+++ b/unsupported/Eigen/src/FFT/ei_fftw_impl.h
@@ -22,6 +22,8 @@
// License and a copy of the GNU General Public License along with
// Eigen. If not, see <http://www.gnu.org/licenses/>.
+namespace Eigen {
+
namespace internal {
// FFTW uses non-const arguments
@@ -269,4 +271,6 @@ namespace internal {
} // end namespace internal
+} // end namespace Eigen
+
/* vim: set filetype=cpp et sw=2 ts=2 ai: */
diff --git a/unsupported/Eigen/src/FFT/ei_kissfft_impl.h b/unsupported/Eigen/src/FFT/ei_kissfft_impl.h
index 04b98b083..c3cbb7f01 100644
--- a/unsupported/Eigen/src/FFT/ei_kissfft_impl.h
+++ b/unsupported/Eigen/src/FFT/ei_kissfft_impl.h
@@ -22,6 +22,8 @@
// License and a copy of the GNU General Public License along with
// Eigen. If not, see <http://www.gnu.org/licenses/>.
+namespace Eigen {
+
namespace internal {
// This FFT implementation was derived from kissfft http:sourceforge.net/projects/kissfft
@@ -426,5 +428,6 @@ struct kissfft_impl
} // end namespace internal
-/* vim: set filetype=cpp et sw=2 ts=2 ai: */
+} // end namespace Eigen
+/* vim: set filetype=cpp et sw=2 ts=2 ai: */